@@ -46,7 +46,7 @@ def fast_object_mode(s):
     s_string = s.astype(str)
     _, indices, counts = np.unique(s_string, return_index=True, return_counts=True)
     index_max = indices[counts.argmax()]
-    return s[index_max]
+    return s.iloc[index_max]
 
 
 class Explainer(ABC):
